=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2010-06-17 11:52:13 +0000
+++ bzrlib/errors.py	2010-06-30 12:03:30 +0000
@@ -3155,4 +3155,10 @@
         "Please, set your name with the 'whoami' command.\n"
         'E.g. bzr whoami "Your Name <name@example.com>"')
 
+class InvalidPattern(BzrError):
+
+    _fmt = ('Invalid pattern(s) found. %(message)s')
+
+    def __init__(self, message):
+        self.message = message
 

=== modified file 'bzrlib/globbing.py'
--- bzrlib/globbing.py	2010-02-17 17:11:16 +0000
+++ bzrlib/globbing.py	2010-06-30 12:03:30 +0000
@@ -23,7 +23,8 @@
 import re
 
 from bzrlib.trace import (
-    warning
+    errors,
+    warning,
     )
 
 
@@ -209,10 +210,17 @@
 
         :return A matching pattern or None if there is no matching pattern.
         """
-        for regex, patterns in self._regex_patterns:
-            match = regex.match(filename)
-            if match:
-                return patterns[match.lastindex -1]
+        try:
+            for regex, patterns in self._regex_patterns:
+                match = regex.match(filename)
+                if match:
+                    return patterns[match.lastindex -1]
+        except errors.InvalidPattern, e:
+            # We can't show the default e.message to the user as thats for
+            # the combined pattern we sent to regex. Instead we indicate to
+            # the user that an ignore file needs fixing.
+            e.message = "File ~/.bazaar/ignore or .bzrignore contains errors."
+            raise e
         return None
 
 class ExceptionGlobster(object):

=== modified file 'bzrlib/lazy_regex.py'
--- bzrlib/lazy_regex.py	2009-03-23 14:59:43 +0000
+++ bzrlib/lazy_regex.py	2010-06-30 12:03:30 +0000
@@ -22,6 +22,8 @@
 
 import re
 
+from bzrlib import errors
+
 
 class LazyRegex(object):
     """A proxy around a real regex, which won't be compiled until accessed."""
@@ -58,7 +60,12 @@
 
     def _real_re_compile(self, *args, **kwargs):
         """Thunk over to the original re.compile"""
-        return _real_re_compile(*args, **kwargs)
+        try:
+            return _real_re_compile(*args, **kwargs)
+        except re.error, e:
+            # raise InvalidPattern instead of re.error as this gives a
+            # cleaner message to the user.
+            raise errors.InvalidPattern('"' + args[0] + '" ' +str(e))
 
     def __getattr__(self, attr):
         """Return a member from the proxied regex object.

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2010-06-17 08:53:15 +0000
+++ bzrlib/log.py	2010-06-30 12:03:30 +0000
@@ -86,7 +86,6 @@
     format_date,
     format_date_with_offset_in_original_timezone,
     get_terminal_encoding,
-    re_compile_checked,
     terminal_width,
     )
 from bzrlib.symbol_versioning import (
@@ -811,8 +810,7 @@
     """
     if search is None:
         return log_rev_iterator
-    searchRE = re_compile_checked(search, re.IGNORECASE,
-            'log message filter')
+    searchRE = re.compile(search, re.IGNORECASE)
     return _filter_message_re(searchRE, log_rev_iterator)
 
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2010-06-29 17:46:25 +0000
+++ bzrlib/osutils.py	2010-06-30 12:03:30 +0000
@@ -2163,29 +2163,6 @@
             raise
 
 
-def re_compile_checked(re_string, flags=0, where=""):
-    """Return a compiled re, or raise a sensible error.
-
-    This should only be used when compiling user-supplied REs.
-
-    :param re_string: Text form of regular expression.
-    :param flags: eg re.IGNORECASE
-    :param where: Message explaining to the user the context where
-        it occurred, eg 'log search filter'.
-    """
-    # from https://bugs.launchpad.net/bzr/+bug/251352
-    try:
-        re_obj = re.compile(re_string, flags)
-        re_obj.search("")
-        return re_obj
-    except re.error, e:
-        if where:
-            where = ' in ' + where
-        # despite the name 'error' is a type
-        raise errors.BzrCommandError('Invalid regular expression%s: %r: %s'
-            % (where, re_string, e))
-
-
 if sys.platform == "win32":
     import msvcrt
     def getchar():

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2010-06-29 16:21:13 +0000
+++ bzrlib/tests/__init__.py	2010-06-30 12:03:30 +0000
@@ -2744,8 +2744,7 @@
     :param pattern: A regular expression string.
     :return: A callable that returns True if the re matches.
     """
-    filter_re = osutils.re_compile_checked(pattern, 0,
-        'test filter')
+    filter_re = re.compile(pattern, 0)
     def condition(test):
         test_id = test.id()
         return filter_re.search(test_id)

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2010-06-25 08:01:24 +0000
+++ bzrlib/tests/blackbox/test_log.py	2010-06-30 12:03:30 +0000
@@ -381,16 +381,13 @@
 
     def test_log_bad_message_re(self):
         """Bad --message argument gives a sensible message
-        
+
         See https://bugs.launchpad.net/bzr/+bug/251352
         """
         self.make_minimal_branch()
         out, err = self.run_bzr(['log', '-m', '*'], retcode=3)
-        self.assertEqual("bzr: ERROR: Invalid regular expression"
-            " in log message filter"
-            ": '*'"
-            ": nothing to repeat\n", err)
-        self.assertEqual('', out)
+        self.assertContainsRe(err, "ERROR.*Invalid pattern.*nothing to repeat")
+        self.assertEqual(out, '')
 
     def test_log_unsupported_timezone(self):
         self.make_linear_branch()

